@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
+@summary: The module for the application object of the get-vsphere-vm-list application.
+
 @author: Frank Brehm
 @contact: frank@brehm-online.com
-@copyright: © 2022 by Frank Brehm, Berlin
-@summary: The module for the application object of the get-vsphere-vm-list application.
+@copyright: © 2025 by Frank Brehm, Berlin
 """
 from __future__ import absolute_import, print_function
 
@@ -12,26 +13,22 @@ from __future__ import absolute_import, print_function
 import logging
 import re
 import sys
-
-from operator import itemgetter, attrgetter
+from operator import attrgetter, itemgetter
 
 # Third party modules
-from fb_tools.common import pp, to_bool
 from fb_tools.argparse_actions import RegexOptionAction
+from fb_tools.common import pp, to_bool
+from fb_tools.spinner import Spinner
 from fb_tools.xlate import format_list
 
 # Own modules
+from . import BaseVmwareApplication, VmwareAppError
 from .. import __version__ as GLOBAL_VERSION
-
+from ..errors import VSphereExpectedError
+from ..vm import VsphereVm
 from ..xlate import XLATOR
 
-from ..spinner import Spinner
-
-from . import BaseVmwareApplication, VmwareAppError
-
-from ..vm import VsphereVm
-
-__version__ = '1.6.4'
+__version__ = '1.7.0'
 LOG = logging.getLogger(__name__)
 
 _ = XLATOR.gettext
@@ -40,15 +37,14 @@ ngettext = XLATOR.ngettext
 
 # =============================================================================
 class GetVmListAppError(VmwareAppError):
-    """ Base exception class for all exceptions in this application."""
+    """Base exception class for all exceptions in this application."""
+
     pass
 
 
 # =============================================================================
 class GetVmListApplication(BaseVmwareApplication):
-    """
-    Class for the application objects.
-    """
+    """Class for the application objects."""
 
     default_vm_pattern = r'.*'
     avail_sort_keys = ('name', 'vsphere', 'cluster', 'path', 'type', 'onl_str', 'cfg_ver', 'os')
@@ -59,10 +55,10 @@ class GetVmListApplication(BaseVmwareApplication):
         self, appname=None, verbose=0, version=GLOBAL_VERSION, base_dir=None,
             initialized=False, usage=None, description=None,
             argparse_epilog=None, argparse_prefix_chars='-', env_prefix=None):
-
+        """Initialize a GetVmListApplication object."""
         desc = _(
-            "Tries to get a list of all virtual machines in "
-            "VMWare VSphere and print it out.")
+            'Tries to get a list of all virtual machines in '
+            'VMWare VSphere and print it out.')
 
         self._vm_pattern = self.default_vm_pattern
         self._details = False
@@ -84,13 +80,13 @@ class GetVmListApplication(BaseVmwareApplication):
     # -------------------------------------------------------------------------
     @property
     def vm_pattern(self):
-        """The regex search pattern for filtering the VM list."""
+        """Return the regex search pattern for filtering the VM list."""
         return self._vm_pattern
 
     # -------------------------------------------------------------------------
     @property
     def details(self):
-        """Should the list be displyed with all details."""
+        """Return whther the list should be displyed with all details."""
         return self._details
 
     @details.setter
@@ -100,7 +96,7 @@ class GetVmListApplication(BaseVmwareApplication):
     # -------------------------------------------------------------------------
     def as_dict(self, short=True):
         """
-        Transforms the elements of the object into a dict
+        Transform the elements of the object into a dict.
 
         @param short: don't include local properties in resulting dict.
         @type short: bool
@@ -108,7 +104,6 @@ class GetVmListApplication(BaseVmwareApplication):
         @return: structure as dict
         @rtype:  dict
         """
-
         res = super(GetVmListApplication, self).as_dict(short=short)
         res['details'] = self.details
         res['vm_pattern'] = self.vm_pattern
@@ -119,26 +114,18 @@ class GetVmListApplication(BaseVmwareApplication):
     # -------------------------------------------------------------------------
     def post_init(self):
         """
-        Method to execute before calling run(). Here could be done some
-        finishing actions after reading in commandline parameters,
-        configuration a.s.o.
-
-        This method could be overwritten by descendant classes, these
-        methhods should allways include a call to post_init() of the
-        parent class.
+        Execute some things before calling run().
 
+        Here could be done some finishing actions after reading in
+        commandline parameters, configuration a.s.o.
         """
-
         super(GetVmListApplication, self).post_init()
 
         self.initialized = True
 
     # -------------------------------------------------------------------------
     def init_arg_parser(self):
-        """
-        Public available method to initiate the argument parser.
-        """
-
+        """Initiate the argument parser."""
         super(GetVmListApplication, self).init_arg_parser()
 
         filter_group = self.arg_parser.add_argument_group(_('Filter options'))
@@ -148,34 +135,34 @@ class GetVmListApplication(BaseVmwareApplication):
             dest='vm_pattern', metavar='REGEX', action=RegexOptionAction,
             topic=_('for names of VMs'), re_options=re.IGNORECASE,
             help=_(
-                "A regular expression to filter the output list of VMs by their name "
-                "(Default: {!r}).").format(self.default_vm_pattern)
+                'A regular expression to filter the output list of VMs by their name '
+                '(Default: {!r}).').format(self.default_vm_pattern)
         )
 
         valid_vm_types = ('all', 'vm', 'template')
         filter_group.add_argument(
             '-T', '--type', metavar=_('TYPE'), dest='vm_type', choices=valid_vm_types,
             default='all', help=_(
-                "Filter output for the type of the VM. Valid values are {li} "
-                "(Default: {dflt!r}).").format(
+                'Filter output for the type of the VM. Valid values are {li} '
+                '(Default: {dflt!r}).').format(
                 dflt='all', li=format_list(valid_vm_types, do_repr=True))
         )
 
         online_filter = filter_group.add_mutually_exclusive_group()
         online_filter.add_argument(
-            '--on', '--online', action="store_true", dest="online",
-            help=_("Filter output for online VMs.")
+            '--on', '--online', action='store_true', dest='online',
+            help=_('Filter output for online VMs.')
         )
         online_filter.add_argument(
-            '--off', '--offline', action="store_true", dest="offline",
-            help=_("Filter output for offline VMs and templates.")
+            '--off', '--offline', action='store_true', dest='offline',
+            help=_('Filter output for offline VMs and templates.')
         )
 
         filter_group.add_argument(
             '-H', '--hw', '--hardware-config', metavar='REGEX', action=RegexOptionAction,
             dest='hw', topic=_('for VMWare hardware config version'), re_options=re.IGNORECASE,
             help=_(
-                "A regular expression to filter the output list of VMs by the VMWare hardware "
+                'A regular expression to filter the output list of VMs by the VMWare hardware '
                 "configuration version (e.g. '{}').").format(r'vmx-0\d$'),
         )
 
@@ -183,29 +170,29 @@ class GetVmListApplication(BaseVmwareApplication):
             '--os', metavar='REGEX', action=RegexOptionAction, dest='os',
             topic=_('for the Operating System version'), re_options=re.IGNORECASE,
             help=_(
-                "A regular expression to filter the output list of VMs by their Operating "
+                'A regular expression to filter the output list of VMs by their Operating '
                 "System version, e.g. '{}'.").format('oracleLinux.*(_64)?Guest')
         )
 
         output_options = self.arg_parser.add_argument_group(_('Output options'))
 
         output_options.add_argument(
-            '-D', '--details', dest='details', action="store_true",
-            help=_("Detailed output list (quering data needs some time longer).")
+            '-D', '--details', dest='details', action='store_true',
+            help=_('Detailed output list (quering data needs some time longer).')
         )
 
         output_options.add_argument(
             '-S', '--sort', metavar='KEY', nargs='+', dest='sort_keys',
             choices=self.avail_sort_keys, help=_(
-                "The keys for sorting the output. Available keys are: {avail}. "
-                "The default sorting keys are: {default}.").format(
+                'The keys for sorting the output. Available keys are: {avail}. '
+                'The default sorting keys are: {default}.').format(
                 avail=format_list(self.avail_sort_keys, do_repr=True),
                 default=format_list(self.default_sort_keys, do_repr=True))
         )
 
     # -------------------------------------------------------------------------
     def perform_arg_parser(self):
-
+        """Evaluate the command line parameters."""
         super(GetVmListApplication, self).perform_arg_parser()
 
         if self.args.details:
@@ -214,17 +201,17 @@ class GetVmListApplication(BaseVmwareApplication):
         if self.args.vm_pattern:
             try:
                 re_name = re.compile(self.args.vm_pattern, re.IGNORECASE)
-                LOG.debug(_("Regular expression for filtering: {!r}").format(re_name.pattern))
+                LOG.debug(_('Regular expression for filtering: {!r}').format(re_name.pattern))
                 self._vm_pattern = self.args.vm_pattern
             except Exception as e:
-                msg = _("Got a {c} for pattern {p!r}: {e}").format(
+                msg = _('Got a {c} for pattern {p!r}: {e}').format(
                     c=e.__class__.__name__, p=self.args.vm_pattern, e=e)
                 LOG.error(msg)
 
         if not self.details:
             if self.args.online or self.args.offline or self.args.hw or self.args.os or \
                     self.args.vm_type != 'all':
-                LOG.info(_("Detailed output is required because of your given options."))
+                LOG.info(_('Detailed output is required because of your given options.'))
                 self.details = True
 
         if self.args.sort_keys:
@@ -237,11 +224,11 @@ class GetVmListApplication(BaseVmwareApplication):
                         self.sort_keys.append(key)
                     else:
                         LOG.warn(_(
-                            "Sorting key {!r} not usable, if not detailed output "
-                            "was given.").format(key))
+                            'Sorting key {!r} not usable, if not detailed output '
+                            'was given.').format(key))
                 if not self.sort_keys:
                     LOG.warn(_(
-                        "No usable sorting keys found, using default sorting keys {}.").format(
+                        'No usable sorting keys found, using default sorting keys {}.').format(
                         format_list(self.default_sort_keys, do_repr=True)))
                     self.sort_keys = self.default_sort_keys
 
@@ -253,12 +240,15 @@ class GetVmListApplication(BaseVmwareApplication):
     # -------------------------------------------------------------------------
     def _run(self):
 
-        LOG.debug(_("Starting {a!r}, version {v!r} ...").format(
+        LOG.debug(_('Starting {a!r}, version {v!r} ...').format(
             a=self.appname, v=self.version))
 
         ret = 0
         try:
             ret = self.get_all_vms()
+        except VSphereExpectedError as e:
+            LOG.error(str(e))
+            self.exit(6)
         finally:
             self.cleaning_up()
 
@@ -266,7 +256,7 @@ class GetVmListApplication(BaseVmwareApplication):
 
     # -------------------------------------------------------------------------
     def get_all_vms(self):
-
+        """Get all VMs from VSphere, maybe filtered."""
         ret = 0
         all_vms = []
 
@@ -276,8 +266,9 @@ class GetVmListApplication(BaseVmwareApplication):
             for vsphere_name in self.vsphere:
                 all_vms += self.get_vms(vsphere_name, re_name)
         elif not self.quiet:
-            spin_prompt = _("Getting all VSPhere VMs ...") + ' '
-            with Spinner(spin_prompt):
+            spin_prompt = _('Getting all VSPhere VMs ...') + ' '
+            spinner_name = self.get_random_spinner_name()
+            with Spinner(spin_prompt, spinner_name):
                 for vsphere_name in self.vsphere:
                     all_vms += self.get_vms(vsphere_name, re_name)
             sys.stdout.write(' ' * len(spin_prompt))
@@ -285,7 +276,7 @@ class GetVmListApplication(BaseVmwareApplication):
             sys.stdout.flush()
 
         if self.verbose > 1:
-            LOG.debug(_("Using sorting keys:") + ' ' + format_list(self.sort_keys, do_repr=True))
+            LOG.debug(_('Using sorting keys:') + ' ' + format_list(self.sort_keys, do_repr=True))
 
         if self.details:
             self.print_vms_detailed(all_vms)
@@ -296,7 +287,7 @@ class GetVmListApplication(BaseVmwareApplication):
 
     # -------------------------------------------------------------------------
     def print_vms(self, all_vms):
-
+        """Print out on STDOUT the list of found VMs."""
         label_list = ('name', 'vsphere', 'path')
         labels = {
             'name': 'Host',
@@ -308,7 +299,7 @@ class GetVmListApplication(BaseVmwareApplication):
 
     # -------------------------------------------------------------------------
     def print_vms_detailed(self, all_vms):
-
+        """Print out on STDOUT the list of found VMs in a detailled way."""
         label_list = self.avail_sort_keys
         labels = {
             'name': 'VM/Template',
@@ -347,8 +338,8 @@ class GetVmListApplication(BaseVmwareApplication):
             max_len += str_lengths[label]
 
         if self.verbose > 1:
-            LOG.debug("Label length:\n" + pp(str_lengths))
-            LOG.debug("Max line length: {} chars".format(max_len))
+            LOG.debug('Label length:\n' + pp(str_lengths))
+            LOG.debug('Max line length: {} chars'.format(max_len))
 
         tpl = ''
         for label in label_list:
@@ -356,7 +347,7 @@ class GetVmListApplication(BaseVmwareApplication):
                 tpl += '  '
             tpl += '{{{la}:<{le}}}'.format(la=label, le=str_lengths[label])
         if self.verbose > 1:
-            LOG.debug(_("Line template: {}").format(tpl))
+            LOG.debug(_('Line template: {}').format(tpl))
 
         if not self.quiet:
             print()
@@ -373,17 +364,17 @@ class GetVmListApplication(BaseVmwareApplication):
         if not self.quiet:
             print()
             if count == 0:
-                msg = _("Found no VMWare VMs.")
+                msg = _('Found no VMWare VMs.')
             else:
                 msg = ngettext(
-                    "Found one VMWare VM.",
-                    "Found {} VMWare VMs.", count).format(count)
+                    'Found one VMWare VM.',
+                    'Found {} VMWare VMs.', count).format(count)
             print(msg)
             print()
 
     # -------------------------------------------------------------------------
     def get_vms(self, vsphere_name, re_name=None):
-
+        """Get the filtered list of VMs from VSPhere."""
         vsphere = self.vsphere[vsphere_name]
         vsphere.get_datacenter()
 
@@ -401,9 +392,9 @@ class GetVmListApplication(BaseVmwareApplication):
 
     # -------------------------------------------------------------------------
     def mangle_vmlist_no_details(self, vm_list, vsphere_name):
-
+        """Prepare the non-detailled data about found VMs for output."""
         if self.verbose > 3:
-            LOG.debug("Mangling VM list:\n" + pp(vm_list))
+            LOG.debug('Mangling VM list:\n' + pp(vm_list))
 
         vms = []
         first = True
@@ -411,7 +402,7 @@ class GetVmListApplication(BaseVmwareApplication):
         for vm in sorted(vm_list, key=itemgetter(0, 1)):
 
             if self.verbose > 2 and first:
-                LOG.debug("VM:\n" + pp(vm))
+                LOG.debug('VM:\n' + pp(vm))
 
             cdata = {
                 'vsphere': vsphere_name,
@@ -425,7 +416,7 @@ class GetVmListApplication(BaseVmwareApplication):
                 cdata['path'] = '/'
 
             if self.verbose > 2 and first:
-                LOG.debug("Mangled VM:\n" + pp(cdata))
+                LOG.debug('Mangled VM:\n' + pp(cdata))
 
             first = False
 
@@ -435,24 +426,24 @@ class GetVmListApplication(BaseVmwareApplication):
 
     # -------------------------------------------------------------------------
     def mangle_vmlist_details(self, vm_list, vsphere_name):
-
+        """Prepare the detailled data about found VMs for output."""
         vms = []
 
         first = True
         for vm in sorted(vm_list, key=attrgetter('name', 'path')):
 
             if not isinstance(vm, VsphereVm):
-                msg = _("Found a {} object:").format(vm.__class__.__name__)
+                msg = _('Found a {} object:').format(vm.__class__.__name__)
                 msg += '\n' + pp(vm)
                 LOG.error(msg)
                 continue
 
             if self.verbose > 2 and first:
-                LOG.debug("VM:\n" + pp(vm.as_dict()))
+                LOG.debug('VM:\n' + pp(vm.as_dict()))
 
             cdata = self._mangle_vm_details(vm, vsphere_name)
             if self.verbose > 2 and first and cdata:
-                LOG.debug("Mangled VM:\n" + pp(cdata))
+                LOG.debug('Mangled VM:\n' + pp(cdata))
 
             first = False
 
@@ -524,7 +515,7 @@ class GetVmListApplication(BaseVmwareApplication):
 
 
 # =============================================================================
-if __name__ == "__main__":
+if __name__ == '__main__':
 
     pass
 
