@@ -1,33 +1,33 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
+@summary: The module for a VSphere ethernet card object.
+
 @author: Frank Brehm
 @contact: frank@brehm-online.com
-@copyright: © 2022 by Frank Brehm, Berlin
-@summary: The module for a VSphere ethernet card object.
+@copyright: © 2025 by Frank Brehm, Berlin
 """
 from __future__ import absolute_import
 
 # Standard modules
-import logging
 import copy
-
+import logging
 try:
     from collections.abc import MutableSequence
 except ImportError:
     from collections import MutableSequence
 
 # Third party modules
-from pyVmomi import vim
-
 from fb_tools.common import pp, to_bool
 from fb_tools.obj import FbBaseObject
 from fb_tools.xlate import format_list
 
+from pyVmomi import vim
+
 # Own modules
 from .xlate import XLATOR
 
-__version__ = '0.3.2'
+__version__ = '1.1.2'
 LOG = logging.getLogger(__name__)
 
 _ = XLATOR.gettext
@@ -35,6 +35,7 @@ _ = XLATOR.gettext
 
 # =============================================================================
 class VsphereEthernetcard(FbBaseObject):
+    """Wrapper class for a vim.vm.device.VirtualEthernetCard object and for its descendants."""
 
     ether_types = {
         'e1000e': 'Virtual E1000e Ethernet adapter',
@@ -54,7 +55,7 @@ class VsphereEthernetcard(FbBaseObject):
             wake_on_lan=False, backing_device=None, backing_type=None, connected=False,
             connect_status=None, connect_on_start=False, allow_guest_control=False,
             ether_type=None, label=None):
-
+        """Initialize the VsphereEthernetcard object."""
         self._unit_nr = None
         self._key = None
         self._address_type = None
@@ -95,9 +96,12 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def unit_nr(self):
-        """The unit number of this device on its controller.
-            This property is None if the controller property is None
-            (for example, when the device is not attached to a specific controller object)."""
+        """
+        Reurn the unit number of this device on its controller.
+
+        This property is None if the controller property is None
+        (for example, when the device is not attached to a specific controller object).
+        """
         return self._unit_nr
 
     @unit_nr.setter
@@ -110,8 +114,11 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def key(self):
-        """A unique key that distinguishes this device from other devices
-            in the same virtual machine."""
+        """
+        Return a unique numeric key of the network device.
+
+        It distinguishes this device from other devices in the same virtual machine.
+        """
         return self._key
 
     @key.setter
@@ -141,8 +148,11 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def external_id(self):
-        """An ID assigned to the virtual network adapter by external
-            management plane or controller."""
+        """
+        Return an external ID assigned to the virtual network adapter.
+
+        It is assigned by external management plane or controller.
+        """
         return self._external_id
 
     @external_id.setter
@@ -159,7 +169,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def mac_address(self):
-        """The MAC address of this virtual ethernet card."""
+        """Return the MAC address of this virtual ethernet card."""
         return self._mac_address
 
     @mac_address.setter
@@ -176,7 +186,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def wake_on_lan(self):
-        """Indicates whether wake-on-LAN is enabled on this virtual network adapter."""
+        """Indicate, whether wake-on-LAN is enabled on this virtual network adapter."""
         return self._wake_on_lan
 
     @wake_on_lan.setter
@@ -186,7 +196,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def backing_device(self):
-        """The name of the backing device of this virtual network adapter."""
+        """Return the name of the backing device of this virtual network adapter."""
         return self._backing_device
 
     @backing_device.setter
@@ -203,7 +213,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def backing_type(self):
-        """The type of the backing device of this virtual network adapter."""
+        """Return the type of the backing device of this virtual network adapter."""
         return self._backing_type
 
     @backing_type.setter
@@ -220,7 +230,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def connected(self):
-        """Indicates whether the device is currently connected."""
+        """Indicate, whether the device is currently connected."""
         return self._connected
 
     @connected.setter
@@ -230,7 +240,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def connect_status(self):
-        """Indicates the current status of the connectable device."""
+        """Indicate the current status of the connectable device."""
         return self._connect_status
 
     @connect_status.setter
@@ -247,7 +257,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def connect_on_start(self):
-        """Specifies whether or not to connect the device when the virtual machine starts."""
+        """Specify, whether or not to connect the device when the virtual machine starts."""
         return self._connect_on_start
 
     @connect_on_start.setter
@@ -257,7 +267,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def allow_guest_control(self):
-        """Enables guest control over whether the connectable device is connected."""
+        """Enable guest control over whether the connectable device is connected."""
         return self._allow_guest_control
 
     @allow_guest_control.setter
@@ -267,7 +277,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -----------------------------------------------------------
     @property
     def ether_type(self):
-        """The type of this virtual network adapter."""
+        """Return the type of this virtual network adapter."""
         return self._ether_type
 
     @ether_type.setter
@@ -300,9 +310,9 @@ class VsphereEthernetcard(FbBaseObject):
 
     # -------------------------------------------------------------------------
     def __eq__(self, other):
-
+        """Magic method for using it as the '=='-operator."""
         if self.verbose > 4:
-            LOG.debug(_("Comparing {} objects ...").format(self.__class__.__name__))
+            LOG.debug(_('Comparing {} objects ...').format(self.__class__.__name__))
 
         if not isinstance(other, VsphereEthernetcard):
             return False
@@ -341,7 +351,7 @@ class VsphereEthernetcard(FbBaseObject):
     # -------------------------------------------------------------------------
     def as_dict(self, short=True, bare=False):
         """
-        Transforms the elements of the object into a dict
+        Transform the elements of the object into a dict.
 
         @param short: don't include local properties in resulting dict.
         @type short: bool
@@ -351,7 +361,6 @@ class VsphereEthernetcard(FbBaseObject):
         @return: structure as dict
         @rtype:  dict
         """
-
         if bare:
             res = {
                 'unit_nr': self.unit_nr,
@@ -391,7 +400,7 @@ class VsphereEthernetcard(FbBaseObject):
 
     # -------------------------------------------------------------------------
     def __copy__(self):
-
+        """Return a new VsphereEthernetcard as a deep copy of the current object."""
         card = VsphereEthernetcard(
             appname=self.appname, verbose=self.verbose, base_dir=self.base_dir,
             initialized=self.initialized, unit_nr=self.unit_nr, key=self.key,
@@ -407,16 +416,34 @@ class VsphereEthernetcard(FbBaseObject):
     # -------------------------------------------------------------------------
     @classmethod
     def from_summary(cls, data, appname=None, verbose=0, base_dir=None, test_mode=False):
-
+        """Create a new VsphereEthernetcard object based on the data given from pyvmomi."""
         if test_mode:
             cls._check_summary_data(data)
         else:
             if not isinstance(data, vim.vm.device.VirtualEthernetCard):
-                msg = _("Parameter {t!r} must be a {e}, {v!r} ({vt}) was given.").format(
+                msg = _('Parameter {t!r} must be a {e}, {v!r} ({vt}) was given.').format(
                     t='data', e='vim.vm.device.VirtualEthernetCard',
                     v=data, vt=data.__class__.__name__)
                 raise TypeError(msg)
 
+        if verbose > 3:
+            LOG.debug('Given ethernet card data:\n' + pp(data))
+
+        eth_class = data.__class__.__name__
+        bclass = data.backing.__class__.__name__
+        bdev = '[unknown]'
+        if hasattr(data.backing, 'deviceName'):
+            bdev = data.backing.deviceName
+        elif isinstance(
+                data.backing,
+                vim.vm.device.VirtualEthernetCard.DistributedVirtualPortBackingInfo):
+            bdev = 'Switch {}'.format(data.backing.port.switchUuid)
+            if hasattr(data.backing.port, 'portKey'):
+                bdev += ', port key {}'.format(data.backing.port.portKey)
+        if verbose > 2:
+            LOG.debug(
+                f'Got ethernet device type {eth_class} - backing device {bdev!r} ({bclass}).')
+
         params = {
             'appname': appname,
             'verbose': verbose,
@@ -428,8 +455,8 @@ class VsphereEthernetcard(FbBaseObject):
             'external_id': data.externalId,
             'mac_address': data.macAddress,
             'wake_on_lan': data.wakeOnLanEnabled,
-            'backing_device': data.backing.deviceName,
-            'backing_type': data.backing.__class__.__name__,
+            'backing_device': bdev,
+            'backing_type': bclass,
             'connected': data.connectable.connected,
             'connect_status': data.connectable.status,
             'connect_on_start': data.connectable.startConnected,
@@ -439,39 +466,47 @@ class VsphereEthernetcard(FbBaseObject):
         if data.deviceInfo:
             params['label'] = data.deviceInfo.label
 
-        if verbose > 2:
-            LOG.debug(_("Checking class of ethernet card: {!r}").format(data.__class__.__name__))
+        params['ether_type'] = cls._get_ethertype(data, verbose)
 
-        try:
-            if isinstance(data, vim.vm.device.VirtualE1000e):
-                params['ether_type'] = 'e1000e'
-            elif isinstance(data, vim.vm.device.VirtualE1000):
-                params['ether_type'] = 'e1000'
-            elif isinstance(data, vim.vm.device.VirtualPCNet32):
-                params['ether_type'] = 'pcnet32'
-            elif isinstance(data, vim.vm.device.VirtualSriovEthernetCard):
-                params['ether_type'] = 'sriov'
-            elif isinstance(data, vim.vm.device.VirtualVmxnet2):
-                params['ether_type'] = 'vmxnet2'
-            elif isinstance(data, vim.vm.device.VirtualVmxnet3Vrdma):
-                params['ether_type'] = 'vmxnet3_rdma'
-            elif isinstance(data, vim.vm.device.VirtualVmxnet3):
-                params['ether_type'] = 'vmxnet3'
-            elif isinstance(data, vim.vm.device.VirtualVmxnet):
-                params['ether_type'] = 'vmxnet'
-        except Exception:
-            pass
-
-        if verbose > 2:
-            LOG.debug(_("Creating {} object from:").format(cls.__name__) + '\n' + pp(params))
+        if verbose > 3:
+            LOG.debug(_('Creating {} object from:').format(cls.__name__) + '\n' + pp(params))
 
         card = cls(**params)
 
-        if verbose > 2:
-            LOG.debug(_("Created {} object:").format(cls.__name__) + '\n' + pp(card.as_dict()))
+        if verbose > 3:
+            LOG.debug(_('Created {} object:').format(cls.__name__) + '\n' + pp(card.as_dict()))
 
         return card
 
+    # -------------------------------------------------------------------------
+    @classmethod
+    def _get_ethertype(cls, data, verbose=0):
+
+        if verbose > 2:
+            LOG.debug(_('Checking class of ethernet card: {!r}').format(data.__class__.__name__))
+
+        try:
+            if isinstance(data, vim.vm.device.VirtualE1000e):
+                return 'e1000e'
+            elif isinstance(data, vim.vm.device.VirtualE1000):
+                return 'e1000'
+            elif isinstance(data, vim.vm.device.VirtualPCNet32):
+                return 'pcnet32'
+            elif isinstance(data, vim.vm.device.VirtualSriovEthernetCard):
+                return 'sriov'
+            elif isinstance(data, vim.vm.device.VirtualVmxnet2):
+                return 'vmxnet2'
+            elif isinstance(data, vim.vm.device.VirtualVmxnet3Vrdma):
+                return 'vmxnet3_rdma'
+            elif isinstance(data, vim.vm.device.VirtualVmxnet3):
+                return 'vmxnet3'
+            elif isinstance(data, vim.vm.device.VirtualVmxnet):
+                return 'vmxnet'
+        except Exception:
+            pass
+
+        return 'unknown'
+
     # -------------------------------------------------------------------------
     @classmethod
     def _check_summary_data(cls, data):
@@ -499,25 +534,23 @@ class VsphereEthernetcard(FbBaseObject):
 
         if len(failing_fields):
             msg = _(
-                "The given parameter {p!r} on calling method {m}() has failing "
-                "attributes").format(p='data', m='from_summary')
+                'The given parameter {p!r} on calling method {m}() has failing '
+                'attributes').format(p='data', m='from_summary')
             msg += ': ' + format_list(failing_fields, do_repr=True)
             raise AssertionError(msg)
 
 
 # =============================================================================
 class VsphereEthernetcardList(FbBaseObject, MutableSequence):
-    """
-    A list containing VsphereEthernetcard objects.
-    """
+    """A list containing VsphereEthernetcard objects."""
 
-    msg_no_ether_card = _("Invalid type {t!r} as an item of a {c}, only {o} objects are allowed.")
+    msg_no_ether_card = _('Invalid type {t!r} as an item of a {c}, only {o} objects are allowed.')
 
     # -------------------------------------------------------------------------
     def __init__(
         self, appname=None, verbose=0, version=__version__, base_dir=None,
             initialized=None, *cards):
-
+        """Initialize a VsphereEthernetcardList object."""
         self._list = []
 
         super(VsphereEthernetcardList, self).__init__(
@@ -533,7 +566,7 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
     # -------------------------------------------------------------------------
     def as_dict(self, short=True, bare=False):
         """
-        Transforms the elements of the object into a dict
+        Transform the elements of the object into a dict.
 
         @param short: don't include local properties in resulting dict.
         @type short: bool
@@ -543,7 +576,6 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
         @return: structure as dict or list
         @rtype:  dict or list
         """
-
         if bare:
             res = []
             for card in self:
@@ -560,7 +592,7 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def __copy__(self):
-
+        """Return a new VsphereEthernetcardList as a deep copy of the current object."""
         new_list = self.__class__(
             appname=self.appname, verbose=self.verbose,
             base_dir=self.base_dir, initialized=False)
@@ -573,13 +605,13 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def index(self, card, *args):
-
+        """Return the numeric index of the given controller in current list."""
         i = None
         j = None
 
         if len(args) > 0:
             if len(args) > 2:
-                raise TypeError(_("{m} takes at most {max} arguments ({n} given).").format(
+                raise TypeError(_('{m} takes at most {max} arguments ({n} given).').format(
                     m='index()', max=3, n=len(args) + 1))
             i = int(args[0])
             if len(args) > 1:
@@ -618,12 +650,12 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
             if item == card:
                 return index
 
-        msg = _("card is not in card list.")
+        msg = _('card is not in card list.')
         raise ValueError(msg)
 
     # -------------------------------------------------------------------------
     def __contains__(self, card):
-
+        """Return whether the given controller is contained in current list."""
         if not isinstance(card, VsphereEthernetcard):
             raise TypeError(self.msg_no_ether_card.format(
                 t=card.__class__.__name__, c=self.__class__.__name__, o='VsphereEthernetcard'))
@@ -639,7 +671,7 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def count(self, card):
-
+        """Return the number of controllers which are equal to the given one in current list."""
         if not isinstance(card, VsphereEthernetcard):
             raise TypeError(self.msg_no_ether_card.format(
                 t=card.__class__.__name__, c=self.__class__.__name__, o='VsphereEthernetcard'))
@@ -655,21 +687,23 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def __len__(self):
+        """Return the number of controllers in current list."""
         return len(self._list)
 
     # -------------------------------------------------------------------------
     def __iter__(self):
-
+        """Iterate through all controllers in current list."""
         for item in self._list:
             yield item
 
     # -------------------------------------------------------------------------
     def __getitem__(self, key):
+        """Get a controller from current list by the given numeric index."""
         return self._list.__getitem__(key)
 
     # -------------------------------------------------------------------------
     def __reversed__(self):
-
+        """Reverse the controllers in list in place."""
         new_list = self.__class__(
             appname=self.appname, verbose=self.verbose,
             base_dir=self.base_dir, initialized=False)
@@ -682,7 +716,7 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def __setitem__(self, key, card):
-
+        """Replace the controller at the given numeric index by the given one."""
         if not isinstance(card, VsphereEthernetcard):
             raise TypeError(self.msg_no_ether_card.format(
                 t=card.__class__.__name__, c=self.__class__.__name__, o='VsphereEthernetcard'))
@@ -691,12 +725,12 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def __delitem__(self, key):
-
+        """Remove the controller at the given numeric index from list."""
         del self._list[key]
 
     # -------------------------------------------------------------------------
     def append(self, card):
-
+        """Append the given controller to the current list."""
         if not isinstance(card, VsphereEthernetcard):
             raise TypeError(self.msg_no_ether_card.format(
                 t=card.__class__.__name__, c=self.__class__.__name__, o='VsphereEthernetcard'))
@@ -705,7 +739,7 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def insert(self, index, card):
-
+        """Insert the given controller in current list at given index."""
         if not isinstance(card, VsphereEthernetcard):
             raise TypeError(self.msg_no_ether_card.format(
                 t=card.__class__.__name__, c=self.__class__.__name__, o='VsphereEthernetcard'))
@@ -714,13 +748,12 @@ class VsphereEthernetcardList(FbBaseObject, MutableSequence):
 
     # -------------------------------------------------------------------------
     def clear(self):
-        "Remove all items from the VsphereEthernetcardList."
-
+        """Remove all items from the VsphereEthernetcardList."""
         self._list = []
 
 
 # =============================================================================
-if __name__ == "__main__":
+if __name__ == '__main__':
 
     pass
 
